# Demonstrating updates and additions  
      
This document was derived from the processing of the file dr_egeria_intro.md; All of the Dr.Egeria statements have been 
preserved (including the generated attributes such as the unique GUIDs) and the explanatory text has been replaced.

In this document we will add glossary categories, update existing terms to categorize them, and add some new terms that
further explain dr.egeria.  This document is being written off-line (actually on a plane) - demonstrating one of the 
intriguing features of dr.egeria - because its just text, it can be edited anywhere and anytime that there is a text 
editor. Dr.Egeria files can be emailed, sent via text message, slack or maintained in a `git` repository. 
It's just text with markdown annotations.

Ok, let's get started. First, we have the `Update Glossary` command below. There is nothing new we need to add at this
point so we can just leave it as-is. When this document is processed it will apply updates but if there are none, 
It doesn't matter.

      
___

Ok, now let's create a couple of glossary categories. They will be:

* **Writing Dr.Egeria Markdown** - where we describe elements of the Dr.Egeria language as terms within the category.
* **Processing Dr.Egeria Markdown** - where we describe the commands for processing Dr.Egeria.
 

Glossary categories have the following attributes:


| Attribute Name  | Input Required? | Read Only | Generated/Default? | Unique? | Notes                                                                                                    |
|:----------------|:----------------|-----------|:-------------------|:--------|:---------------------------------------------------------------------------------------------------------|
| Category Name   | Yes             | No        | No                 | No      | A display name (informal name).                                                                          |
| Owning Glossary | Yes             | No        | No                 | Yes     | This is the qualified name of the glossary that owns this category.                                      |
| Parent Category | No              | No        | No                 | No      | Indicate parent category, if exists.                                                                     |
| Description     | No              | No        | No                 | No      | A textual description of this category                                                                   |
| Member Terms    | No              | No        | No                 | No      | A list of terms that are members of this category                                                        |
| Qualified Name  | No              | No        | Yes                | Yes     | The qualified name can either be provided by the user or generated. If generated, a pattern is followed. |
| GUID            | No              | Yes       | Yes                | Yes     | GUIDs are always generated by Egeria. They are meant for automation, not people.                         |
| Table           | No              | Yes       | Yes                | No      | Under development                                                                                        |
| Graph           | No              | Yes       | Yes                | No      | Under Development                                                                                        |
Qualified Names can either be user specified or generated. If generated the following the form:
`{local-qualifier}:{type}:{display name}`

* Local-Qualifier is an optional string that can be useful to both disambiguate similar names and to add some local context. Local qualifiers could be set to organization names, functions, business context, etc. The settings for a local qualifier is set either by setting the environment variable `EGERIA_LOCAL_QUALIFIER` or by passing in a parameter when executing one of the Dr.Egeria enabled commands. This could also be set for a team by an Egeria administrator.

___

# Create Category  
  
## Category Name  
  
Writing Dr.Egeria Markdown  
  
## Owning Glossary  
  
Glossary::Egeria-Markdown  

## Parent Category

  
## Description  
  
These terms describe the elements of the Dr.Egeria Markdown language and how to use them.   
  
## Member Terms

## <Qualified Name>  
  
## <GUID>  


___

# Create Category  
  
## Category Name  
  
Dr.Egeria Actions
  
## Owning Glossary  
  
Glossary::Egeria-Markdown  

## Parent Category

Writing Dr.Egeria Markdown

## Description  
  
The actions that Dr. Egeria can process.
  
  
## <Qualified Name>  
  
## <GUID>  

___

# Create Category  
  
## Category Name  
  
Command Attributes
  
## Owning Glossary  
  
Glossary::Egeria-Markdown  

## Parent Category
Writing Dr. Egeria Markdown
## Description  
  
Common attributes of commands
   
___

# Create Category  
  
## Category Name  
  
Dr.Egeria Verbs
  
## Owning Glossary  
  
Glossary::Egeria-Markdown  
  
## Description  

Kinds of actions Dr.Egeria can take.


## Parent Category
Writing Dr.Egeria Markdown

## Child Category
  
Dr.Egeria Actions

___

# Create Category  
  
## Category Name  
  
Processing Dr.Egeria Markdown  
  
## Owning Glossary  
  
Glossary::Egeria-Markdown  

## Parent Category
  
## Description  
  
These terms describe commands to process Dr.Egeria Markdown.  

## Terms

Command, Source, Directive, Display Validate, Process
   
## <Qualified Name>  
  
## <GUID>  
  
___  
  
# List Categories

  
  
